@@ -23,6 +23,7 @@
 #include "ui/viewscontainer.h"
 #include "ui/tray.h"
 #include "ui/droptarget.h"
+#include "ui/newtransferdialog.h"
 
 #include <kapplication.h>
 #include <kstandarddirs.h>
@@ -121,7 +122,7 @@ void MainWindow::setupActions()
 
     QAction *renameGroupAction = actionCollection()->addAction("rename_groups");
     renameGroupAction->setText(i18n("Rename Group"));
-    renameGroupAction->setIcon(KIcon("todolist"));
+    renameGroupAction->setIcon(KIcon("editinput"));
     connect(renameGroupAction, SIGNAL(triggered()), SLOT(slotRenameGroup()));
 
     m_autoPasteAction = new KToggleAction(KIcon("klipper"),
@@ -227,9 +228,11 @@ void MainWindow::slotDelayedInit()
     //Here we import the user's transfers.
     KGet::load( KStandardDirs::locateLocal("appdata", "transfers.kgt") );
 
-    // DockWidget
     m_dock = new Tray(this);
-    m_dock->show();
+    if(Settings::enableSystemTray()) {
+        // DockWidget
+        m_dock->show();
+    }
 
     // enable dropping
     setAcceptDrops(true);
@@ -288,7 +291,7 @@ void MainWindow::slotToggleDropTarget()
 
 void MainWindow::slotNewTransfer()
 {
-    KGet::addTransfer(KUrl());
+    NewTransferDialog::showNewTransferDialog();
 }
 
 void MainWindow::slotImportTransfers()
@@ -504,6 +507,8 @@ void MainWindow::slotNewConfig()
     // PreferencesDialog, this function is called.
 
     m_drop->setVisible(Settings::showDropTarget(), false);
+    m_dock->setVisible(Settings::enableSystemTray());
+    if(!Settings::enableSystemTray()) setVisible(true);
 
     slotKonquerorIntegration(Settings::konquerorIntegration());
     m_konquerorIntegration->setChecked(Settings::konquerorIntegration());
@@ -579,7 +584,12 @@ void MainWindow::slotShowMenubar()
 void MainWindow::closeEvent( QCloseEvent * e )
 {
     e->ignore();
-    hide();
+    if(!Settings::enableSystemTray()) {
+        slotQuit();
+    }
+    else {
+        hide();
+    }
 }
 
 void MainWindow::dragEnterEvent(QDragEnterEvent * event)
@@ -637,4 +647,9 @@ QVariantMap MainWindow::transfers() const
     return m_dbusModelObserver->transfers();
 }
 
+int MainWindow::transfersSpeed() const
+{
+    return m_dbusModelObserver->transfersSpeed();
+}
+
 #include "mainwindow.moc"
