@@ -1,7 +1,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: edit.cpp 659674 2007-04-30 16:06:09Z lunakl $
+ * $Id: edit.cpp 719634 2007-10-01 15:06:16Z ereslibre $
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
  *
@@ -1217,7 +1217,7 @@ PhoneNumberDialog::PhoneNumberDialog(QWidget *parent)
     setButtons( Ok|Cancel );
     setDefaultButton( Ok );
     setModal( true );
-  KWindowSystem::setIcons(winId(), qApp->windowIcon().pixmap(IconSize(K3Icon::Desktop),IconSize(K3Icon::Desktop)), qApp->windowIcon().pixmap(IconSize(K3Icon::Small),IconSize(K3Icon::Small)));
+  KWindowSystem::setIcons(winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop)), qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),IconSize(KIconLoader::Small)));
 
   QWidget *hbox = new QWidget(this);
   QHBoxLayout *hboxLayout2 = new QHBoxLayout(hbox);
