@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: pppdata.cpp 704673 2007-08-25 18:53:49Z amth $
+ * $Id: pppdata.cpp 721935 2007-10-06 09:51:00Z apaku $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -29,6 +29,7 @@
 #include "devices.h"
 #include <klocale.h>
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kmessagebox.h>
 #include <kapplication.h>
 #include <kglobalsettings.h>
@@ -71,8 +72,6 @@ bool PPPData::open() {
   }
 
   // don't expand shell variables
-  config->setDollarExpansion(false);
-
   accounthighcount = readNumConfig(GENERAL_GRP, NUMACCOUNTS_KEY, 0) - 1;
 
   if (accounthighcount > MAX_ACCOUNTS)
