@@ -91,6 +91,11 @@ MainWindow::MainWindow(QWidget *parent)
 
     if (Settings::showStartPage())
         createStartPage();
+
+    setAutoSaveSettings(); // e.g toolbar position, mainwindow size, ...
+
+    if (Settings::rememberSessions()) // give some time to create and show the window first
+        QTimer::singleShot(100, this, SLOT(restoreOpenSessions()));
 }
 
 MainWindow::~MainWindow()
@@ -204,13 +209,25 @@ void MainWindow::setupActions()
     connect(m_bookmarkManager, SIGNAL(openUrl(KUrl)), SLOT(slotNewConnection(KUrl)));
 }
 
+void MainWindow::restoreOpenSessions()
+{
+    QStringList list = Settings::openSessions();
+    QStringList::Iterator it = list.begin();
+    QStringList::Iterator end = list.end();
+    while (it != end) {
+        slotNewConnection(*it);
+        ++it;
+    }
+}
+
 void MainWindow::slotNewConnection(const KUrl &newUrl, bool switchFullscreenWhenConnected)
 {
     m_switchFullscreenWhenConnected = switchFullscreenWhenConnected;
 
     KUrl url = newUrl.isEmpty() ? m_addressNavigator->uncommittedUrl() : newUrl;
 
-    if (!url.isValid()) {
+    if (!url.isValid() || (url.host().isEmpty() && url.port()<0)
+        || !url.path().isEmpty()) {
         KMessageBox::error(this,
                            i18n("The entered address does not have the required form."),
                            i18n("Malformed URL"));
@@ -282,6 +299,7 @@ void MainWindow::resizeTabWidget(int w, int h)
     if ((newWindowSize.height() >= desktopSize.height()) || (newWindowSize.width() >= desktopSize.width())) {
         kDebug(5010) << "remote desktop needs more place than available -> show window maximized";
         showMaximized();
+        QCoreApplication::processEvents();
         return;
     }
 
@@ -311,7 +329,7 @@ void MainWindow::statusChanged(RemoteView::RemoteStatus status)
         message = i18n("Connecting to %1", host);
         break;
     case RemoteView::Authenticating:
-        iconName = "password";
+        iconName = "dialog-password";
         message = i18n("Authenticating at %1", host);
         break;
     case RemoteView::Preparing:
@@ -391,6 +409,9 @@ void MainWindow::slotSwitchFullscreen()
         fullscreenLayout->addWidget(scrollArea);
         m_fullscreenWindow->setLayout(fullscreenLayout);
 
+        MinimizePixel *minimizePixel = new MinimizePixel(m_fullscreenWindow);
+        connect(minimizePixel, SIGNAL(rightClicked()), m_fullscreenWindow, SLOT(showMinimized()));
+
         m_fullscreenWindow->show();
 
         m_fullscreenWindow->setWindowState(Qt::WindowFullScreen);
@@ -463,8 +484,6 @@ void MainWindow::showRemoteViewToolbar()
 {
     kDebug(5010) << "showRemoteViewToolbar";
 
-    m_remoteViewList.at(m_currentRemoteView)->repaint(); // be sure there are no artifacts on the remote view
-
     if (!m_toolBar) {
         actionCollection()->action("switch_fullscreen")->setIcon(KIcon("view-restore"));
         actionCollection()->action("switch_fullscreen")->setText(i18n("Switch to Window Mode"));
@@ -472,6 +491,13 @@ void MainWindow::showRemoteViewToolbar()
         m_toolBar = new FloatingToolBar(m_fullscreenWindow, m_fullscreenWindow);
         m_toolBar->setSide(FloatingToolBar::Top);
         m_toolBar->addAction(actionCollection()->action("switch_fullscreen"));
+
+        QAction *minimizeAction = new QAction(m_toolBar);
+        minimizeAction->setIcon(KIcon("window-suppressed"));
+        minimizeAction->setText(i18n("Minimize Fullscreen Window"));
+        connect(minimizeAction, SIGNAL(triggered()), m_fullscreenWindow, SLOT(showMinimized()));
+        m_toolBar->addAction(minimizeAction);
+
         m_toolBar->addAction(actionCollection()->action("take_screenshot"));
         m_toolBar->addAction(actionCollection()->action("view_only"));
         m_toolBar->addAction(actionCollection()->action("show_local_cursor"));
@@ -483,7 +509,6 @@ void MainWindow::showRemoteViewToolbar()
         stickToolBarAction->setIcon(KIcon("note2"));
         stickToolBarAction->setText(i18n("S&tick Toolbar"));
         connect(stickToolBarAction, SIGNAL(triggered(bool)), m_toolBar, SLOT(setSticky(bool)));
-
         m_toolBar->addAction(stickToolBarAction);
     }
 
@@ -602,7 +627,17 @@ void MainWindow::closeEvent(QCloseEvent *event)
             KStandardGuiItem::yes(), KStandardGuiItem::no(), KStandardGuiItem::cancel(),
             "AskBeforeExit") == KMessageBox::Yes) {
 
+        if (Settings::rememberSessions()) { // remember open remote views for next startup
+            QStringList list;
+            for (int i = m_showStartPage ? 1 : 0; i < m_tabWidget->count(); i++) {
+                kDebug(5010) << m_remoteViewList.at(i - 1)->url();
+                list.append(m_remoteViewList.at(i - 1)->url().prettyUrl(KUrl::RemoveTrailingSlash));
+            }
+            Settings::setOpenSessions(list);
+        }
+
         Settings::self()->writeConfig();
+
         event->accept();
     } else
         event->ignore();
@@ -674,8 +709,8 @@ void MainWindow::newVncConnection()
 
     QToolTip::showText(m_addressNavigator->pos() + pos() + QPoint(m_addressNavigator->width(),
                                                                   m_addressNavigator->height() + 20),
-                       i18n("Enter here the address.<br />"
-                            "<i>Example: vncserver:1 (host:port / screen)</i>"), this);
+                       i18n("<html>Enter here the address.<br />"
+                            "<i>Example: vncserver:1 (host:port / screen)</i></html>"), this);
 }
 
 void MainWindow::newRdpConnection()
@@ -685,8 +720,8 @@ void MainWindow::newRdpConnection()
 
     QToolTip::showText(m_addressNavigator->pos() + pos() + QPoint(m_addressNavigator->width(),
                                                                   m_addressNavigator->height() + 20),
-                       i18n("Enter here the address. Port is optional.<br />"
-                            "<i>Example: rdpserver:3389 (host:port)</i>"), this);
+                       i18n("<html>Enter here the address. Port is optional.<br />"
+                            "<i>Example: rdpserver:3389 (host:port)</i></html>"), this);
 }
 
 QList<RemoteView *> MainWindow::remoteViewList() const
