@@ -14,13 +14,14 @@
 #include "invitation.h"
 
 
-class InvitationManager;
+class InvitationManagerPrivate;
 /**
 	@author Alessandro Praduroux <pradu@pradu.it>
 */
 class InvitationManager : public QObject
 {
 Q_OBJECT
+friend class InvitationManagerPrivate;
 public:
     static InvitationManager *self();
 
