@@ -194,12 +194,14 @@ void SetupWizard::setupSearchPage()
                         "whether or not they are samba servers.<br />"
                         "Don\'t use it if your network is very large, i.e. more than 1000 hosts.<br />"),m_searchPage);
    info->setWordWrap(true);
+   info->setTextFormat(Qt::RichText);
    m_nmblookup=new QCheckBox(i18n("Send NetBIOS broadcasts"),m_searchPage);
    info=new QLabel(i18n("You need to have the samba package (nmblookup) installed.<br />"
                         "Only samba/windows servers will respond.<br />"
                         "This method is not very reliable.<br />"
                         "You should enable it if you are part of a large network."),m_searchPage);
    info->setTextFormat(Qt::RichText);
+   info->setWordWrap(true);
    QWidget *dummy=new QWidget(m_searchPage);
    m_searchPage->setStretchFactor(dummy,10);
    m_searchPage->setSpacing(KDialog::spacingHint());
@@ -241,11 +243,11 @@ void SetupWizard::setupAddressesPage()
 void SetupWizard::setupAllowedPage()
 {
    m_allowedAddressesPage=new KVBox(this);
-   QLabel* info=new QLabel(i18n("This is a security related setting.<br />"
+   QLabel* info=new QLabel(i18n("<qt>This is a security related setting.<br />"
                                 "It provides a simple IP address based way to specify \"trusted\" hosts.<br />"
                                 "Only hosts which fit into the addresses given here are accepted by LISa as clients. "
                                 "The list of hosts published by LISa will also only contain hosts which fit into this scheme.<br />"
-                                "Usually you enter your IP address/network mask here."),m_allowedAddressesPage);
+                                "Usually you enter your IP address/network mask here.</qt>"),m_allowedAddressesPage);
    info->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
    info->setWordWrap( true );
    m_allowedAddresses=new KRestrictedLine(m_allowedAddressesPage);
@@ -256,7 +258,7 @@ void SetupWizard::setupAllowedPage()
    m_allowedAddressesPage->setStretchFactor(dummy,10);
    m_allowedAddressesPage->setSpacing(KDialog::spacingHint());
    //m_allowedAddressesPage->setMargin(KDialog::marginHint());
-   info=new QLabel(i18n("<b>If unsure, keep it as is.</b>"), m_allowedAddressesPage);
+   info=new QLabel(i18n("<qt><b>If unsure, keep it as is.</b></qt>"), m_allowedAddressesPage);
    info->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
    setHelpEnabled( m_allowedAddressesPage, false );
@@ -265,21 +267,21 @@ void SetupWizard::setupAllowedPage()
 void SetupWizard::setupBcastPage()
 {
    m_bcastPage=new KVBox(this);
-   QLabel *info=new QLabel(i18n("<br />Enter your IP address and network mask here, like <code>192.168.0.1/255.255.255.0</code>"),m_bcastPage);
+   QLabel *info=new QLabel(i18n("<qt><br />Enter your IP address and network mask here, like <code>192.168.0.1/255.255.255.0</code></qt>"),m_bcastPage);
    info->setAlignment(Qt::AlignLeft|Qt::AlignVCenter );
    info->setWordWrap( true );
    m_bcastAddress=new KRestrictedLine(m_bcastPage);
    m_bcastAddress->setValidChars("0123456789./");
-   info=new QLabel(i18n("<br />To reduce the network load, the LISa servers in one network<br />"
+   info=new QLabel(i18n("<qt><br />To reduce the network load, the LISa servers in one network<br />"
                         "cooperate with each other. Therefore you have to enter the broadcast<br />"
                         "address here. If you are connected to more than one network, choose <br />"
-                        "one of the broadcast addresses."),m_bcastPage);
+                        "one of the broadcast addresses.</qt>"),m_bcastPage);
    info->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
    info->setWordWrap( true );
    QWidget *dummy=new QWidget(m_bcastPage);
    m_bcastPage->setStretchFactor(dummy,10);
    m_bcastPage->setSpacing(KDialog::spacingHint());
-   info=new QLabel(i18n("<b>If unsure, keep it as is.</b>"), m_bcastPage);
+   info=new QLabel(i18n("<qt><b>If unsure, keep it as is.</b></qt>"), m_bcastPage);
    info->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
    m_bcastPage->setSpacing(KDialog::spacingHint());
@@ -303,6 +305,7 @@ void SetupWizard::setupUpdateIntervalPage()
                         "So if you enter 300 sec = 5 min here, this does not mean that LISa will ping "
                         "your whole network every 5 minutes. The interval will increase up to 16 x 5 min = 80 min."),m_intervalPage);
    info->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
+   info->setTextFormat(Qt::RichText);
    info->setWordWrap( true );
    QWidget *dummy=new QWidget(m_intervalPage);
    m_intervalPage->setStretchFactor(dummy,10);
@@ -484,12 +487,12 @@ void SetupWizard::showPage(QWidget* page)
       if (m_ping->isChecked())
          text+=i18n("You can use the same syntax as on the previous page.<br />");
       else
-         text+=i18n("There are three ways to specify IP addresses:<br />"
+         text+=i18n("<qt>There are three ways to specify IP addresses:<br />"
                     "1. IP address/network mask, like<code> 192.168.0.0/255.255.255.0;</code><br />"
                     "2. continuous ranges, like<code> 10.0.1.0-10.0.1.200;</code><br />"
                     "3. single IP addresses, like<code> 10.0.0.23;</code><br />"
                     "You can also enter combinations of 1 to 3, separated by \";\", <br />"
-                    "like<code> 192.168.0.0/255.255.255.0;10.0.0.0;10.0.1.1-10.0.1.100;</code><br />");
+                    "like<code> 192.168.0.0/255.255.255.0;10.0.0.0;10.0.1.1-10.0.1.100;</code><br /></qt>");
       m_trustedHostsLabel->setText(text);
       m_allowedAddresses->setFocus();
    }
